==> developer-center-api-2.1.3-20170517.075557-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/appextra/DuibaShareDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.appextra;

import java.io.Serializable;

/**
 * Created by xiaoxuda on 2016/11/18.
 */
public class DuibaShareDto implements Serializable {
    private static final long serialVersionUID = 1561548228519381496L;

    private Boolean isDuibaShare;
    private String shareLandUrl;
    private String shareAndroidLink;
    private String shareIosLink;
    private Boolean isActivityShare;
    private Long appId;
    private String shareAndroidLinkActivity;
    private String shareIosLinkActivity;

    public DuibaShareDto() {
    }

    public String getShareIosLinkActivity() {
        return shareIosLinkActivity;
    }

    public void setShareIosLinkActivity(String shareIosLinkActivity) {
        this.shareIosLinkActivity = shareIosLinkActivity;
    }

    public String getShareAndroidLinkActivity() {
        return shareAndroidLinkActivity;
    }

    public void setShareAndroidLinkActivity(String shareAndroidLinkActivity) {
        this.shareAndroidLinkActivity = shareAndroidLinkActivity;
    }

    public DuibaShareDto(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Boolean getIsActivityShare() {
        return isActivityShare;
    }

    public void setIsActivityShare(Boolean isActivityShare) {
        this.isActivityShare = isActivityShare;
    }

    public String getShareIosLink() {
        return shareIosLink;
    }

    public void setShareIosLink(String shareIosLink) {
        this.shareIosLink = shareIosLink;
    }

    public String getShareAndroidLink() {
        return shareAndroidLink;
    }

    public void setShareAndroidLink(String shareAndroidLink) {
        this.shareAndroidLink = shareAndroidLink;
    }

    public Boolean getIsDuibaShare() {
        return isDuibaShare;
    }

    public void setIsDuibaShare(Boolean isDuibaShare) {
        this.isDuibaShare = isDuibaShare;
    }

    public String getShareLandUrl() {
        return shareLandUrl;
    }

    public void setShareLandUrl(String shareLandUrl) {
        this.shareLandUrl = shareLandUrl;
    }


}

==> developer-center-api-3.9.1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/appextra/DuibaShareDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.appextra;

import java.io.Serializable;

/**
 * Created by xiaoxuda on 2016/11/18.
 */
public class DuibaShareDto implements Serializable {
    private static final long serialVersionUID = 1561548228519381496L;

    private Boolean isDuibaShare;
    private String shareLandUrl;
    private String shareAndroidLink;
    private String shareIosLink;
    private Boolean isActivityShare;
    private Long appId;
    private String shareAndroidLinkActivity;
    private String shareIosLinkActivity;
    private String shareDesc;
    private Boolean isInfoGet;
    private String shareImage;
    private String shareLogo;
    private String shareButtonName;
    private String wakeupAppLink;

    public DuibaShareDto() {
    }

    public String getWakeupAppLink() {
        return wakeupAppLink;
    }

    public void setWakeupAppLink(String wakeupAppLink) {
        this.wakeupAppLink = wakeupAppLink;
    }

    public String getShareLogo() {
        return shareLogo;
    }

    public void setShareLogo(String shareLogo) {
        this.shareLogo = shareLogo;
    }

    public String getShareButtonName() {
        return shareButtonName;
    }

    public void setShareButtonName(String shareButtonName) {
        this.shareButtonName = shareButtonName;
    }

    public String getShareImage() {
        return shareImage;
    }

    public void setShareImage(String shareImage) {
        this.shareImage = shareImage;
    }

    public String getShareDesc() {
        return shareDesc;
    }

    public Boolean getIsInfoGet() {
        return isInfoGet;
    }

    public void setIsInfoGet(Boolean isInfoGet) {
        this.isInfoGet = isInfoGet;
    }

    public void setShareDesc(String shareDesc) {
        this.shareDesc = shareDesc;
    }

    public String getShareIosLinkActivity() {
        return shareIosLinkActivity;
    }

    public void setShareIosLinkActivity(String shareIosLinkActivity) {
        this.shareIosLinkActivity = shareIosLinkActivity;
    }

    public String getShareAndroidLinkActivity() {
        return shareAndroidLinkActivity;
    }

    public void setShareAndroidLinkActivity(String shareAndroidLinkActivity) {
        this.shareAndroidLinkActivity = shareAndroidLinkActivity;
    }

    public DuibaShareDto(Long appId) {
        this.appId = appId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Boolean getIsActivityShare() {
        return isActivityShare;
    }

    public void setIsActivityShare(Boolean isActivityShare) {
        this.isActivityShare = isActivityShare;
    }

    public String getShareIosLink() {
        return shareIosLink;
    }

    public void setShareIosLink(String shareIosLink) {
        this.shareIosLink = shareIosLink;
    }

    public String getShareAndroidLink() {
        return shareAndroidLink;
    }

    public void setShareAndroidLink(String shareAndroidLink) {
        this.shareAndroidLink = shareAndroidLink;
    }

    public Boolean getIsDuibaShare() {
        return isDuibaShare;
    }

    public void setIsDuibaShare(Boolean isDuibaShare) {
        this.isDuibaShare = isDuibaShare;
    }

    public String getShareLandUrl() {
        return shareLandUrl;
    }

    public void setShareLandUrl(String shareLandUrl) {
        this.shareLandUrl = shareLandUrl;
    }


}
